==> jc-1.4.0.tar.gz: gnu/java/net/protocol/file/Connection__24StaticData.h <==
// class gnu.java.net.protocol.file.Connection$StaticData

// class file dependencies
// @dep_class 3b98aff90a4191fd gnu_java_net_protocol_file_Connection__24StaticData
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_
#define _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_SimpleDateFormat$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$refs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object	_jc_gnu_java_net_protocol_file_Connection__24StaticData$object;

typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct	_jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct {
	struct _jc_java_text_SimpleDateFormat$object	*dateFormat;
	struct _jc_java_lang_String$object	*lineSeparator;
};
extern _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_file_Connection__24StaticData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object *);

// Static methods
extern void _jc_gnu_java_net_protocol_file_Connection__24StaticData$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods {
};

// Vtable
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods	gnu_java_net_protocol_file_Connection__24StaticData;
};

// Vtype
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$refs {
    _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs	gnu_java_net_protocol_file_Connection__24StaticData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs	gnu_java_net_protocol_file_Connection__24StaticData;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object {
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype	*vtype;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype _jc_gnu_java_net_protocol_file_Connection__24StaticData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_file_Connection__24StaticData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_file_Connection__24StaticData$class_object;

#endif	/* _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/file/Connection__24StaticData.h <==
// class gnu.java.net.protocol.file.Connection$StaticData

// class file dependencies
// @dep_class f91cc680a0bfeaed gnu_java_net_protocol_file_Connection__24StaticData
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_
#define _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_SimpleDateFormat$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$refs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs	_jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object	_jc_gnu_java_net_protocol_file_Connection__24StaticData$object;

typedef struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct	_jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable;
typedef const struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct {
	struct _jc_java_text_SimpleDateFormat$object	*dateFormat;
	struct _jc_java_lang_String$object	*lineSeparator;
};
extern _jc_gnu_java_net_protocol_file_Connection__24StaticData$fields_struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_file_Connection__24StaticData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_net_protocol_file_Connection__24StaticData$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods {
};

// Vtable
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vmethods	gnu_java_net_protocol_file_Connection__24StaticData;
};

// Vtype
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$refs {
    _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_refs	gnu_java_net_protocol_file_Connection__24StaticData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_file_Connection__24StaticData$sub_nonrefs	gnu_java_net_protocol_file_Connection__24StaticData;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_file_Connection__24StaticData$object {
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype	*vtype;
	_jc_gnu_java_net_protocol_file_Connection__24StaticData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_file_Connection__24StaticData$vtype _jc_gnu_java_net_protocol_file_Connection__24StaticData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_file_Connection__24StaticData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_file_Connection__24StaticData$class_object;

#endif	/* _JC_gnu_java_net_protocol_file_Connection__24StaticData_H_ */
